@@ -17,7 +17,7 @@ pub struct FragmentDeriveInput {
     #[darling(default)]
     query_module: Option<SpannedValue<String>>,
     #[darling(default, rename = "schema_module")]
-    schema_module_: Option<SpannedValue<String>>,
+    schema_module_: Option<syn::Path>,
 
     #[darling(default)]
     pub graphql_type: Option<SpannedValue<String>>,
@@ -26,15 +26,14 @@ pub struct FragmentDeriveInput {
 }
 
 impl FragmentDeriveInput {
-    pub fn schema_module(&self) -> SpannedValue<String> {
+    pub fn schema_module(&self) -> syn::Path {
         if let Some(schema_module) = &self.schema_module_ {
             return schema_module.clone();
         }
         if let Some(query_module) = &self.query_module {
-            return query_module.clone();
+            return syn::parse_str(query_module).unwrap();
         }
-
-        SpannedValue::new("schema".into(), Span::call_site())
+        syn::parse2(quote::quote! { schema }).unwrap()
     }
 
     pub fn graphql_type_name(&self) -> String {
@@ -58,7 +57,7 @@ impl FragmentDeriveInput {
                 self.ident.span(),
                 format!(
                     "At least one field should be selected for `{}`.",
-                    self.ident.to_string()
+                    self.ident
                 ),
             )
             .into());
@@ -322,7 +321,7 @@ mod tests {
             )),
             schema_path: "abcd".to_string().into(),
             query_module: None,
-            schema_module_: Some("abcd".to_string().into()),
+            schema_module_: Some(syn::parse2(quote::quote! { abcd }).unwrap()),
             graphql_type: Some("abcd".to_string().into()),
             argument_struct: None,
         };
@@ -341,7 +340,7 @@ mod tests {
             )),
             schema_path: "abcd".to_string().into(),
             query_module: None,
-            schema_module_: Some("abcd".to_string().into()),
+            schema_module_: Some(syn::parse2(quote::quote! { abcd }).unwrap()),
             graphql_type: Some("abcd".to_string().into()),
             argument_struct: None,
         };
@@ -394,7 +393,7 @@ mod tests {
             )),
             schema_path: "abcd".to_string().into(),
             query_module: None,
-            schema_module_: Some("abcd".to_string().into()),
+            schema_module_: Some(syn::parse2(quote::quote! { abcd }).unwrap()),
             graphql_type: None,
             argument_struct: None,
         };
