@@ -16,7 +16,6 @@ mod module;
 mod schema;
 mod suggestions;
 mod type_index;
-mod type_path;
 mod type_validation;
 
 pub use ident::RenameAll;
@@ -27,18 +26,6 @@ use field_type::FieldType;
 use ident::Ident;
 use schema::{load_schema, SchemaLoadError};
 use type_index::TypeIndex;
-use type_path::TypePath;
-
-#[deprecated(
-    since = "0.13.0",
-    note = "output_query_dsl is deprecated, use output_schema_module"
-)]
-pub fn output_query_dsl(
-    schema: impl AsRef<std::path::Path>,
-    output_path: impl AsRef<std::path::Path>,
-) -> Result<(), SchemaLoadError> {
-    output_schema_module(schema, output_path)
-}
 
 pub fn output_schema_module(
     schema: impl AsRef<std::path::Path>,
