@@ -31,28 +31,23 @@ pub fn check_spread_type(rust_type: &syn::Type) -> Result<(), syn::Error> {
 
     match parsed_type {
         ParsedType::Unknown => {
-            Err(syn::Error::new(
-                rust_type.span(),
-                "Cynic does not understand this type. Only un-parameterised types, Vecs, Options & Box are accepted currently.",
-            ))
-        },
+            // If we can't parse the type just ignore it - the compiler will still tell us if it's
+            // wrong.
+            Ok(())
+        }
         ParsedType::Box(inner) => {
             // Box is a transparent container for the purposes of checking compatability
             // so just recurse
             check_spread_type(inner)
         }
-        ParsedType::Optional(_) => {
-            Err(syn::Error::new(
-                rust_type.span(),
-                "You can't spread on an Option type"
-            ))
-        }
-        ParsedType::List(_) => {
-            Err(syn::Error::new(
-                rust_type.span(),
-                "You can't spread on a Vec"
-            ))
-        }
+        ParsedType::Optional(_) => Err(syn::Error::new(
+            rust_type.span(),
+            "You can't spread on an Option type",
+        )),
+        ParsedType::List(_) => Err(syn::Error::new(
+            rust_type.span(),
+            "You can't spread on a Vec",
+        )),
         ParsedType::SimpleType => {
             // No way to tell if the given type is actually compatible,
             // but the rust compiler should help us with that.
@@ -68,19 +63,10 @@ fn normal_check(
 ) -> Result<(), syn::Error> {
     let parsed_type = parse_type(rust_type);
 
-    match parsed_type {
-        ParsedType::Unknown => {
-            return Err(syn::Error::new(
-                rust_type.span(),
-                "Cynic does not understand this type. Only un-parameterised types, Vecs, Options & Box are accepted currently.",
-            ))
-        },
-        ParsedType::Box(inner) => {
-            // Box is a transparent container for the purposes of checking compatability
-            // so just recurse
-            return normal_check(gql_type, inner, flattening);
-        }
-        _ => {}
+    if let ParsedType::Box(inner) = parsed_type {
+        // Box is a transparent container for the purposes of checking compatability
+        // so just recurse
+        return normal_check(gql_type, inner, flattening);
     }
 
     if gql_type.is_nullable() {
@@ -176,13 +162,16 @@ fn parse_type(ty: &'_ syn::Type) -> ParsedType<'_> {
 
                 return ParsedType::Unknown;
             }
+
             if last_segment.ident.to_string() == "Option" {
                 if let Some(inner_type) = extract_generic_argument(last_segment) {
                     return ParsedType::Optional(inner_type);
                 }
 
                 return ParsedType::Unknown;
-            } else if last_segment.ident.to_string() == "Vec" {
+            }
+
+            if last_segment.ident.to_string() == "Vec" {
                 if let Some(inner_type) = extract_generic_argument(last_segment) {
                     return ParsedType::List(inner_type);
                 }
@@ -190,7 +179,7 @@ fn parse_type(ty: &'_ syn::Type) -> ParsedType<'_> {
                 return ParsedType::Unknown;
             }
 
-            if last_segment.arguments == syn::PathArguments::None {
+            if let syn::PathArguments::None = last_segment.arguments {
                 return ParsedType::SimpleType;
             }
         }
@@ -224,8 +213,8 @@ mod tests {
 
     #[test]
     fn test_required_validation() {
-        let required_field = FieldType::Scalar(Ident::new("test").into(), false);
-        let optional_field = FieldType::Scalar(Ident::new("test").into(), true);
+        let required_field = FieldType::Scalar(Ident::new("test"), false);
+        let optional_field = FieldType::Scalar(Ident::new("test"), true);
 
         assert_matches!(
             check_types_are_compatible(
@@ -235,6 +224,14 @@ mod tests {
             ),
             Ok(())
         );
+        assert_matches!(
+            check_types_are_compatible(
+                &required_field,
+                &syn::parse2(quote! { DateTime<Utc> }).unwrap(),
+                CheckMode::Normal
+            ),
+            Ok(())
+        );
         assert_matches!(
             check_types_are_compatible(
                 &optional_field,
@@ -264,17 +261,13 @@ mod tests {
     #[test]
     fn test_list_validation() {
         let list = FieldType::List(
-            Box::new(FieldType::Scalar(Ident::new("test").into(), false)),
+            Box::new(FieldType::Scalar(Ident::new("test"), false)),
             false,
         );
-        let optional_list = FieldType::List(
-            Box::new(FieldType::Scalar(Ident::new("test").into(), false)),
-            true,
-        );
-        let option_list_option = FieldType::List(
-            Box::new(FieldType::Scalar(Ident::new("test").into(), true)),
-            true,
-        );
+        let optional_list =
+            FieldType::List(Box::new(FieldType::Scalar(Ident::new("test"), false)), true);
+        let option_list_option =
+            FieldType::List(Box::new(FieldType::Scalar(Ident::new("test"), true)), true);
 
         assert_matches!(
             check_types_are_compatible(
@@ -300,6 +293,30 @@ mod tests {
             ),
             Ok(())
         );
+        assert_matches!(
+            check_types_are_compatible(
+                &list,
+                &syn::parse2(quote! { Vec<DateTime<Utc>> }).unwrap(),
+                CheckMode::Normal
+            ),
+            Ok(())
+        );
+        assert_matches!(
+            check_types_are_compatible(
+                &optional_list,
+                &syn::parse2(quote! { Option<Vec<DateTime<Utc>>> }).unwrap(),
+                CheckMode::Normal
+            ),
+            Ok(())
+        );
+        assert_matches!(
+            check_types_are_compatible(
+                &option_list_option,
+                &syn::parse2(quote! { Option<Vec<Option<DateTime<Utc>>>> }).unwrap(),
+                CheckMode::Normal
+            ),
+            Ok(())
+        );
         assert_matches!(
             check_types_are_compatible(
                 &list,
@@ -324,22 +341,26 @@ mod tests {
             ),
             Err(_)
         );
+        assert_matches!(
+            check_types_are_compatible(
+                &option_list_option,
+                &syn::parse2(quote! { Option<DateTime<Vec<Option<i32>>>> }).unwrap(),
+                CheckMode::Normal
+            ),
+            Err(_)
+        );
     }
 
     #[test]
     fn test_validation_when_flattening() {
         let list = FieldType::List(
-            Box::new(FieldType::Scalar(Ident::new("test").into(), false)),
+            Box::new(FieldType::Scalar(Ident::new("test"), false)),
             false,
         );
-        let optional_list = FieldType::List(
-            Box::new(FieldType::Scalar(Ident::new("test").into(), false)),
-            true,
-        );
-        let option_list_option = FieldType::List(
-            Box::new(FieldType::Scalar(Ident::new("test").into(), true)),
-            true,
-        );
+        let optional_list =
+            FieldType::List(Box::new(FieldType::Scalar(Ident::new("test"), false)), true);
+        let option_list_option =
+            FieldType::List(Box::new(FieldType::Scalar(Ident::new("test"), true)), true);
 
         assert_matches!(
             check_types_are_compatible(
@@ -386,18 +407,18 @@ mod tests {
 
     #[rstest(graphql_field, rust_field,
         case::required_t(
-            FieldType::Scalar(Ident::new("T").into(), false),
+            FieldType::Scalar(Ident::new("T"), false),
             parse_quote! { Option<Box<T>> }
         ),
 
         case::optional_t(
-            FieldType::Scalar(Ident::new("T").into(), true),
+            FieldType::Scalar(Ident::new("T"), true),
             parse_quote! { Option<T> }
         ),
 
         case::option_vec_required_t(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), false)),
+                Box::new(FieldType::Scalar(Ident::new("T"), false)),
                 true
             ),
             parse_quote! { Option<Vec<T>> }
@@ -405,7 +426,7 @@ mod tests {
 
         case::required_vec_required_t(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), false)),
+                Box::new(FieldType::Scalar(Ident::new("T"), false)),
                 false
             ),
             parse_quote! { Option<Vec<T>> }
@@ -420,33 +441,33 @@ mod tests {
 
     #[rstest(graphql_field, rust_field,
         case::required_t_box(
-            FieldType::Scalar(Ident::new("T").into(), false),
+            FieldType::Scalar(Ident::new("T"), false),
             parse_quote! { Box<T> }
         ),
         case::required_t_standalone(
-            FieldType::Scalar(Ident::new("T").into(), false),
+            FieldType::Scalar(Ident::new("T"), false),
             parse_quote! { T }
         ),
 
         case::optional_t_standalone(
-            FieldType::Scalar(Ident::new("T").into(), true),
+            FieldType::Scalar(Ident::new("T"), true),
             parse_quote! { T }
         ),
         case::optional_t_box(
-            FieldType::Scalar(Ident::new("T").into(), true),
+            FieldType::Scalar(Ident::new("T"), true),
             parse_quote! { Box<T> }
         ),
 
         case::option_vec_required_t(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), false)),
+                Box::new(FieldType::Scalar(Ident::new("T"), false)),
                 true
             ),
             parse_quote! { Vec<T> }
         ),
         case::option_vec_required_t(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), false)),
+                Box::new(FieldType::Scalar(Ident::new("T"), false)),
                 true
             ),
             parse_quote! { Vec<Option<T>> }
@@ -454,14 +475,14 @@ mod tests {
 
         case::required_vec_required_t(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), false)),
+                Box::new(FieldType::Scalar(Ident::new("T"), false)),
                 false
             ),
             parse_quote! { Vec<T> }
         ),
         case::required_vec_required_t_no_vec(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), false)),
+                Box::new(FieldType::Scalar(Ident::new("T"), false)),
                 false
             ),
             parse_quote! { T }
@@ -469,14 +490,14 @@ mod tests {
 
         case::required_vec_optional_t_no_vec(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), true)),
+                Box::new(FieldType::Scalar(Ident::new("T"), true)),
                 false
             ),
             parse_quote! { Option<T> }
         ),
         case::required_vec_optional_t_wrong_nesting(
             FieldType::List(
-                Box::new(FieldType::Scalar(Ident::new("T").into(), true)),
+                Box::new(FieldType::Scalar(Ident::new("T"), true)),
                 false
             ),
             parse_quote! { Option<Vec<T>> }
