@@ -1,4 +1,4 @@
-use crate::{Errors, FieldType, Ident, TypePath};
+use crate::{Errors, FieldType, Ident};
 use proc_macro2::TokenStream;
 
 /// A parmeter to a schema function that represents a GraphQL parameter.
@@ -15,7 +15,7 @@ impl ArgumentParameter {
         }
     }
 
-    pub fn to_tokens(&self, path_to_markers: TypePath) -> Result<TokenStream, Errors> {
+    pub fn to_tokens(&self, path_to_markers: syn::Path) -> Result<TokenStream, Errors> {
         use quote::quote;
 
         let name = &self.name;
@@ -34,10 +34,10 @@ impl ArgumentParameterType {
         ArgumentParameterType { argument_type }
     }
 
-    pub fn to_tokens(&self, path_to_markers: TypePath) -> Result<TokenStream, Errors> {
+    pub fn to_tokens(&self, path_to_markers: syn::Path) -> Result<TokenStream, Errors> {
         use quote::quote;
 
-        let type_lock = self.argument_type.as_type_lock(path_to_markers);
+        let type_lock = self.argument_type.as_type_lock(&path_to_markers);
         let wrapper_path = self.argument_type.wrapper_path()?;
 
         Ok(quote! { impl ::cynic::InputType<#type_lock, #wrapper_path> })
